@@ -16,13 +16,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -750,8 +750,8 @@ static Image *ReadGRAYImage(const ImageInfo *image_info,ExceptionInfo *exception
         AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
-            image=DestroyImageList(image);
-            return((Image *) NULL);
+            status=MagickFalse;
+            break;
           }
         image=SyncNextImageInList(image);
         status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
@@ -804,7 +804,7 @@ ModuleExport size_t RegisterGRAYImage(void)
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw gray samples");
-  entry->module=ConstantString("GRAY");
+  entry->magick_module=ConstantString("GRAY");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("GRAYA");
   entry->decoder=(DecodeImageHandler *) ReadGRAYImage;
@@ -812,7 +812,7 @@ ModuleExport size_t RegisterGRAYImage(void)
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->description=ConstantString("Raw gray and alpha samples");
-  entry->module=ConstantString("GRAY");
+  entry->magick_module=ConstantString("GRAY");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
@@ -868,7 +868,8 @@ ModuleExport void UnregisterGRAYImage(void)
 %    o image:  The image.
 %
 */
-static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,Image *image)
+static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,
+  Image *image)
 {
   MagickBooleanType
     status;
@@ -883,6 +884,7 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,Image *image
     quantum_type;
 
   size_t
+    imageListLength,
     length;
 
   ssize_t
@@ -914,6 +916,7 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,Image *image
   if (LocaleCompare(image_info->magick,"GRAYA") == 0)
     quantum_type=GrayAlphaQuantum;
   scene=0;
+  imageListLength=GetImageListLength(image);
   do
   {
     /*
@@ -1130,8 +1133,7 @@ static MagickBooleanType WriteGRAYImage(const ImageInfo *image_info,Image *image
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    status=SetImageProgress(image,SaveImagesTag,scene++,
-      GetImageListLength(image));
+    status=SetImageProgress(image,SaveImagesTag,scene++,imageListLength);
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
