@@ -121,7 +121,7 @@ ModuleExport size_t RegisterPS2Image(void)
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("Level II Encapsulated PostScript");
   entry->mime_type=ConstantString("application/postscript");
-  entry->module=ConstantString("PS2");
+  entry->magick_module=ConstantString("PS2");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PS2");
   entry->encoder=(EncodeImageHandler *) WritePS2Image;
@@ -129,7 +129,7 @@ ModuleExport size_t RegisterPS2Image(void)
   entry->blob_support=MagickFalse;
   entry->description=ConstantString("Level II PostScript");
   entry->mime_type=ConstantString("application/postscript");
-  entry->module=ConstantString("PS2");
+  entry->magick_module=ConstantString("PS2");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
