@@ -17,13 +17,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -125,12 +125,12 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Open image file.
   */
   assert(image_info != (const ImageInfo *) NULL);
-  assert(image_info->signature == MagickSignature);
+  assert(image_info->signature == MagickCoreSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
-  assert(exception->signature == MagickSignature);
+  assert(exception->signature == MagickCoreSignature);
   image=AcquireImage(image_info);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
@@ -154,11 +154,16 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   canvas_image=CloneImage(image,image->extract_info.width,1,MagickFalse,
     exception);
+  if (canvas_image == (Image *) NULL)
+    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   (void) SetImageVirtualPixelMethod(canvas_image,BlackVirtualPixelMethod);
   quantum_type=GrayQuantum;
   quantum_info=AcquireQuantumInfo(image_info,canvas_image);
   if (quantum_info == (QuantumInfo *) NULL)
-    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+    {
+      canvas_image=DestroyImage(canvas_image);
+      ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+    }
   pixels=(const unsigned char *) NULL;
   if (image_info->number_scenes != 0)
     while (image->scene < image_info->scene)
@@ -196,6 +201,8 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
         length=GetQuantumExtent(canvas_image,quantum_info,quantum_type);
         pixels=(const unsigned char *) ReadBlobStream(image,length,
           GetQuantumPixels(quantum_info),&count);
+        if (count != (ssize_t) length)
+          break;
       }
     for (y=0; y < (ssize_t) image->extract_info.height; y++)
     {
@@ -251,6 +258,8 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
       pixels=(const unsigned char *) ReadBlobStream(image,length,
         GetQuantumPixels(quantum_info),&count);
+      if (count != (ssize_t) length)
+        break;
     }
     SetQuantumImageType(image,quantum_type);
     /*
@@ -267,8 +276,8 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
         AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
-            image=DestroyImageList(image);
-            return((Image *) NULL);
+            status=MagickFalse;
+            break;
           }
         image=SyncNextImageInList(image);
         status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
@@ -322,7 +331,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw red samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("C");
   entry->decoder=(DecodeImageHandler *) ReadRAWImage;
@@ -331,7 +340,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw cyan samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("G");
   entry->decoder=(DecodeImageHandler *) ReadRAWImage;
@@ -340,7 +349,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw green samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("M");
   entry->decoder=(DecodeImageHandler *) ReadRAWImage;
@@ -349,7 +358,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw magenta samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("B");
   entry->decoder=(DecodeImageHandler *) ReadRAWImage;
@@ -358,7 +367,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw blue samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("Y");
   entry->decoder=(DecodeImageHandler *) ReadRAWImage;
@@ -367,7 +376,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw yellow samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("A");
   entry->decoder=(DecodeImageHandler *) ReadRAWImage;
@@ -376,7 +385,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw alpha samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("O");
   entry->decoder=(DecodeImageHandler *) ReadRAWImage;
@@ -385,7 +394,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw opacity samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("K");
   entry->decoder=(DecodeImageHandler *) ReadRAWImage;
@@ -394,7 +403,7 @@ ModuleExport size_t RegisterRAWImage(void)
   entry->endian_support=MagickTrue;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Raw black samples");
-  entry->module=ConstantString("RAW");
+  entry->magick_module=ConstantString("RAW");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
@@ -473,6 +482,7 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
     *p;
 
   size_t
+    imageListLength,
     length;
 
   ssize_t
@@ -486,9 +496,9 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
     Open output image file.
   */
   assert(image_info != (const ImageInfo *) NULL);
-  assert(image_info->signature == MagickSignature);
+  assert(image_info->signature == MagickCoreSignature);
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
@@ -571,6 +581,7 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
     }
   }
   scene=0;
+  imageListLength=GetImageListLength(image);
   do
   {
     /*
@@ -602,8 +613,7 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    status=SetImageProgress(image,SaveImagesTag,scene++,
-      GetImageListLength(image));
+    status=SetImageProgress(image,SaveImagesTag,scene++,imageListLength);
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
